==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hardwaresecuritymodules/kotlin/outputs/SystemDataResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hardwaresecuritymodules.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Metadata pertaining to creation and last modification of dedicated hsm resource.
 * @property createdAt The timestamp of dedicated hsm resource creation (UTC).
 * @property createdBy The identity that created dedicated hsm resource.
 * @property createdByType The type of identity that created dedicated hsm resource.
 * @property lastModifiedAt The timestamp of dedicated hsm resource last modification (UTC).
 * @property lastModifiedBy The identity that last modified dedicated hsm resource.
 * @property lastModifiedByType The type of identity that last modified dedicated hsm resource.
 */
public data class SystemDataResponse(
    public val createdAt: String? = null,
    public val createdBy: String? = null,
    public val createdByType: String? = null,
    public val lastModifiedAt: String? = null,
    public val lastModifiedBy: String? = null,
    public val lastModifiedByType: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.hardwaresecuritymodules.outputs.SystemDataResponse):
            SystemDataResponse = SystemDataResponse(
            createdAt = javaType.createdAt().map({ args0 -> args0 }).orElse(null),
            createdBy = javaType.createdBy().map({ args0 -> args0 }).orElse(null),
            createdByType = javaType.createdByType().map({ args0 -> args0 }).orElse(null),
            lastModifiedAt = javaType.lastModifiedAt().map({ args0 -> args0 }).orElse(null),
            lastModifiedBy = javaType.lastModifiedBy().map({ args0 -> args0 }).orElse(null),
            lastModifiedByType = javaType.lastModifiedByType().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/hardwaresecuritymodules/kotlin/outputs/SystemDataResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hardwaresecuritymodules.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Metadata pertaining to creation and last modification of dedicated hsm resource.
 * @property createdAt The timestamp of dedicated hsm resource creation (UTC).
 * @property createdBy The identity that created dedicated hsm resource.
 * @property createdByType The type of identity that created dedicated hsm resource.
 * @property lastModifiedAt The timestamp of dedicated hsm resource last modification (UTC).
 * @property lastModifiedBy The identity that last modified dedicated hsm resource.
 * @property lastModifiedByType The type of identity that last modified dedicated hsm resource.
 */
public data class SystemDataResponse(
    public val createdAt: String? = null,
    public val createdBy: String? = null,
    public val createdByType: String? = null,
    public val lastModifiedAt: String? = null,
    public val lastModifiedBy: String? = null,
    public val lastModifiedByType: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.hardwaresecuritymodules.outputs.SystemDataResponse): SystemDataResponse = SystemDataResponse(
            createdAt = javaType.createdAt().map({ args0 -> args0 }).orElse(null),
            createdBy = javaType.createdBy().map({ args0 -> args0 }).orElse(null),
            createdByType = javaType.createdByType().map({ args0 -> args0 }).orElse(null),
            lastModifiedAt = javaType.lastModifiedAt().map({ args0 -> args0 }).orElse(null),
            lastModifiedBy = javaType.lastModifiedBy().map({ args0 -> args0 }).orElse(null),
            lastModifiedByType = javaType.lastModifiedByType().map({ args0 -> args0 }).orElse(null),
        )
    }
}
